==> qtjambi-multimedia-debuginfo-linux-x64-6.5.5.jar: sources/QtJambiMultimedia/QAudioOutput_shell.h <==
#ifndef QAUDIOOUTPUT_SHELL_H
#define QAUDIOOUTPUT_SHELL_H

#include <QtCore/QtGlobal>
#include <QtCore/qcompilerdetection.h>

QT_WARNING_DISABLE_DEPRECATED
QT_WARNING_DISABLE_GCC("-Wdeprecated-declarations")

#include <QtMultimedia/qaudiooutput.h>
#include <QtJambi/QtJambiAPI>
#include <QtCore/QList>
#include <QtCore/QVariant>
#include <QtCore/qbindingstorage.h>
#include <QtCore/qbytearray.h>
#include <QtCore/qcoreevent.h>
#include <QtCore/qmetaobject.h>
#include <QtCore/qnamespace.h>
#include <QtCore/qobject.h>
#include <QtCore/qproperty.h>
#include <qtcore-config.h>
#if QT_CONFIG(regularexpression)
#include <QtCore/qregularexpression.h>
#endif //QT_CONFIG(regularexpression)
#include <QtCore/qthread.h>
#include <QtCore/qtimer.h>
#include <QtMultimedia/qaudiodevice.h>
#include <QtJambi/RegistryAPI>


class QAudioOutput_shell : public QAudioOutput, public QtJambiShellInterface
{
public:
    QAudioOutput_shell(const QAudioDevice& device0, QObject* parent1 = nullptr);
    QAudioOutput_shell(QObject* parent0 = nullptr);
    ~QAudioOutput_shell() override;

    void childEvent(QChildEvent* event0) override;
    void connectNotify(const QMetaMethod& signal0) override;
    void customEvent(QEvent* event0) override;
    void disconnectNotify(const QMetaMethod& signal0) override;
    bool event(QEvent* event0) override;
    bool eventFilter(QObject* watched0, QEvent* event1) override;
    void timerEvent(QTimerEvent* event0) override;
    static void operator delete(void * ptr) noexcept;
    const QMetaObject *metaObject() const override final;
    void *qt_metacast(const char *) override final;
    int qt_metacall(QMetaObject::Call, int, void **) override final;
private:
    QtJambiShell* __shell() const override final;
    jmethodID __shell_javaMethod(int pos) const;
};

struct QAudioOutput_access : public QAudioOutput
{
};

#endif // QAUDIOOUTPUT_SHELL_H

==> qtjambi-multimedia-debuginfo-linux-x64-6.5.7.jar: sources/QtJambiMultimedia/QAudioOutput_shell.h <==
#ifndef QAUDIOOUTPUT_SHELL_H
#define QAUDIOOUTPUT_SHELL_H

#include <QtCore/QtGlobal>
#include <QtCore/qcompilerdetection.h>

QT_WARNING_DISABLE_DEPRECATED
QT_WARNING_DISABLE_GCC("-Wdeprecated-declarations")

#include <QtMultimedia/qaudiooutput.h>
#include <QtJambi/QtJambiAPI>
#include <QtCore/QList>
#include <QtCore/QVariant>
#include <QtCore/qbindingstorage.h>
#include <QtCore/qbytearray.h>
#include <QtCore/qcoreevent.h>
#include <QtCore/qmetaobject.h>
#include <QtCore/qnamespace.h>
#include <QtCore/qobject.h>
#include <QtCore/qproperty.h>
#include <qtcore-config.h>
#if QT_CONFIG(regularexpression)
#include <QtCore/qregularexpression.h>
#endif //QT_CONFIG(regularexpression)
#include <QtCore/qthread.h>
#include <QtCore/qtimer.h>
#include <QtMultimedia/qaudiodevice.h>
#include <QtJambi/RegistryAPI>


class QAudioOutput_shell : public QAudioOutput, public QtJambiShellInterface
{
public:
    QAudioOutput_shell(const QAudioDevice& device0, QObject* parent1 = nullptr);
    QAudioOutput_shell(QObject* parent0 = nullptr);
    ~QAudioOutput_shell() override;
    static void operator delete(void * ptr) noexcept;
private:
    QtJambiShell* __shell() const override final;
    friend class QAudioOutput_mshell;
    friend class QAudioOutput_oshell;
};


class QAudioOutput_mshell : public QAudioOutput_shell
{
public:
    using QAudioOutput_shell::QAudioOutput_shell;
    static void operator delete(void * ptr) noexcept;
    const QMetaObject *metaObject() const override final;
    void *qt_metacast(const char *) override final;
    int qt_metacall(QMetaObject::Call, int, void **) override final;
};


class QAudioOutput_oshell : public QAudioOutput_mshell
{
public:
    using QAudioOutput_mshell::QAudioOutput_mshell;
    void childEvent(QChildEvent* event0) override;
    void connectNotify(const QMetaMethod& signal0) override;
    void customEvent(QEvent* event0) override;
    void disconnectNotify(const QMetaMethod& signal0) override;
    bool event(QEvent* event0) override;
    bool eventFilter(QObject* watched0, QEvent* event1) override;
    void timerEvent(QTimerEvent* event0) override;
    static void operator delete(void * ptr) noexcept;
private:
    jmethodID __shell_javaMethod(int pos) const;
};

struct QAudioOutput_access : public QAudioOutput
{
};

#endif // QAUDIOOUTPUT_SHELL_H
